# Copyright (C) 2009-2011 W. Trevor King <wking@drexel.edu>
#
# This file is part of pypiezo.
#
# pypiezo is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# pypiezo is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pypiezo.  If not, see <http://www.gnu.org/licenses/>.

"Tools for controlling piezoelectric actuators."

from distutils.core import setup
from os import walk
import os.path

from pypiezo import __version__


classifiers = """\
Development Status :: 2 - Pre-Alpha
Intended Audience :: Developers
Intended Audience :: Science/Research
Operating System :: POSIX
Operating System :: Unix
License :: OSI Approved :: GNU General Public License (GPL)
Programming Language :: Python
Topic :: Scientific/Engineering
Topic :: Software Development :: Libraries :: Python Modules
"""

def find_packages(root='pypiezo'):
    packages = []
    prefix = '.'+os.path.sep
    for dirpath,dirnames,filenames in walk(root):
        if '__init__.py' in filenames:
            if dirpath.startswith(prefix):
                dirpath = dirpath[len(prefix):]
            packages.append(dirpath.replace(os.path.sep, '.'))
    return packages

_this_dir = os.path.dirname(__file__)
packages = find_packages()

setup(name='pypiezo',
      version=__version__,
      maintainer='W. Trevor King',
      maintainer_email='wking@drexel.edu',
      url='http://www.physics.drexel.edu/~wking/unfolding-disasters/pypiezo/',
      download_url='http://www.physics.drexel.edu/~wking/code/python/pypiezo-%s.tar.gz' % __version__,
      license='GNU General Public License (GPL)',
      platforms=['all'],
      description=__doc__,
      long_description=open(os.path.join(_this_dir, 'README'), 'r').read(),
      classifiers=filter(None, classifiers.split('\n')),
      packages=packages,
      provides=['pypiezo (%s)' % __version__],
      requires=['pycomedi (>= 0.3)'],
      )
